<!doctype html>
<html>
    <head>
        <!-- Latest compiled and minified CSS -->
        <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css" integrity="sha384-Gn5384xqQ1aoWXA+058RXPxPg6fy4IWvTNh0E263XmFcJlSAwiGgFAW/dAiS6JXm" crossorigin="anonymous">
    </head>

    <body>
        <div class="container">
            <h1>Bootstrap 3</h1>
            <a href="{% url 'bootstrap3' %}">View examples</a>
            <br><br>
            <h1>Bootstrap 4</h1>
            <a href="{% url 'bootstrap4' %}">View examples</a>
        </div>
    </body>
</html>

